@@ -7,7 +7,7 @@ Configuration options for Command behavior.
 from __future__ import annotations
 
 from enum import Enum
-from typing import TYPE_CHECKING, Optional, Any, Union, Callable, Type, TypeVar, overload, Generic, Sequence, Dict
+from typing import TYPE_CHECKING, Optional, Any, Union, Callable, Type, TypeVar, Generic, Sequence, overload, Dict
 
 from .utils import FixedFlag, MissingMixin, _NotSet
 
@@ -18,10 +18,18 @@ if TYPE_CHECKING:
     from .formatting.params import ParamHelpFormatter
     from .typing import Bool, ParamOrGroup, CommandType
 
-__all__ = ['CommandConfig', 'ShowDefaults', 'OptionNameMode', 'SubcommandAliasHelpMode', 'DEFAULT_CONFIG']
+__all__ = [
+    'CommandConfig',
+    'ShowDefaults',
+    'OptionNameMode',
+    'SubcommandAliasHelpMode',
+    'AmbiguousComboMode',
+    'DEFAULT_CONFIG',
+]
 
-_ConfigValue = TypeVar('_ConfigValue')
-ConfigValue = Union[_ConfigValue, Any]
+CV = TypeVar('CV')
+DV = TypeVar('DV')
+ConfigValue = Union[CV, DV]
 
 
 # region Config Option Enums
@@ -150,13 +158,33 @@ def _cmd_alias_mode(mode: CmdAliasMode) -> CmdAliasMode:
         return mode
 
 
+class AmbiguousComboMode(MissingMixin, Enum):
+    """
+    Options for handling potentially ambiguous combinations of short forms of Option / Flag / etc. Parameters.
+
+    The behavior based on each supported option:
+
+    :IGNORE: Ignore potentially ambiguous combinations of short options entirely.  Best effort parsing will be
+      performed.
+    :PERMISSIVE: Allow multi-char short options that overlap with a single char one for exact matches, but reject any
+      user input that combines multiple short options when the combination contains a sequence that could be
+      interpreted as a multi-char short option.
+    :STRICT: Reject multi-char short options that overlap with a single char one before parsing, regardless of user
+      input.
+    """
+
+    IGNORE = 'ignore'           # Ignore potentially ambiguous combinations of short options entirely
+    PERMISSIVE = 'permissive'   # Allow multi-char short options that overlap with a single char one for exact matches
+    STRICT = 'strict'           # Reject multi-char short options that overlap with a single char one before parsing
+
+
 # endregion
 
 
-class ConfigItem(Generic[_ConfigValue]):
+class ConfigItem(Generic[CV, DV]):
     __slots__ = ('default', 'type', 'name')
 
-    def __init__(self, default: ConfigValue, type: Callable[[Any], _ConfigValue] = None):  # noqa
+    def __init__(self, default: DV, type: Callable[[Any], CV] = None):  # noqa
         self.default = default
         self.type = type
 
@@ -179,19 +207,16 @@ class ConfigItem(Generic[_ConfigValue]):
         raise KeyError
 
     @overload
-    def __get__(self, instance: None, owner: Type[CommandConfig]) -> ConfigItem[_ConfigValue]:
+    def __get__(self, instance: None, owner: Type[CommandConfig]) -> ConfigItem[CV, DV]:
         ...
 
     @overload
     def __get__(self, instance: CommandConfig, owner: Type[CommandConfig]) -> ConfigValue:
         ...
 
-    def __get__(
-        self, instance: Optional[CommandConfig], owner: Type[CommandConfig]
-    ) -> Union[ConfigItem[_ConfigValue], ConfigValue]:
+    def __get__(self, instance, owner):
         if instance is None:
             return self
-
         try:
             return self.get_value(instance)
         except KeyError:
@@ -259,6 +284,9 @@ class CommandConfig:
     #: Whether ambiguous combinations of positional choices should result in an :class:`.AmbiguousParseTree` error
     reject_ambiguous_pos_combos: Bool = ConfigItem(False, bool)  # EXPERIMENTAL
 
+    #: How potentially ambiguous combinations of short forms of Option/Flag/etc. Parameters should be handled
+    ambiguous_short_combos: AmbiguousComboMode = ConfigItem(AmbiguousComboMode.PERMISSIVE, AmbiguousComboMode)
+
     # endregion
 
     # region Usage & Help Text Options
